<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-svp?lang_cible=ru
// ** ne pas modifier le fichier **

return [

	// S
	'svp_description' => 'Этот модуль предоставляет API и интерфейс для управления плагинами SPIP.',
	'svp_slogan' => 'Управление плагинами',
];
